package com.inteligr8.git;

import java.net.URISyntaxException;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.eclipse.jgit.transport.URIish;

public class GitUrl {

	private static final Pattern gitUrlPattern = Pattern.compile("(((ssh|http(s)?)://([^@]+@)?([^:/]+)(:[0-9]+)?/)|git@([^:]+):)([\\w\\.@\\:/\\-~]+)(\\.git)");
	
	private final String url;
	private final String hostname;
	private final String fullyQualifiedRepositoryName;
	
	public GitUrl(URIish url) {
		this.url = url.toString();
		
		Matcher matcher = gitUrlPattern.matcher(url.toString());
		if (!matcher.find())
			throw new IllegalArgumentException("The '" + url + "' URL does not match the expected pattern: " + gitUrlPattern.toString());

		this.hostname = matcher.group(6) != null ? matcher.group(6) : matcher.group(8);
		this.fullyQualifiedRepositoryName = matcher.group(9);
	}
	
	public GitUrl(String url) throws URISyntaxException {
		this(new URIish(url));
	}
	
	public String getUrl() {
		return this.url;
	}
	
	public String getHostname() {
		return this.hostname;
	}
	
	public String getFullyQualifiedRepositoryName() {
		return this.fullyQualifiedRepositoryName;
	}

}
